import { Nullable } from "./TypescriptUtils";
export declare type AbstractDomNode = AbstractDomElement | string;
export declare type DomElementChildren = AbstractDomNode[];
export declare type DomElementChildrenFrom = Nullable<AbstractDomNode> | Nullable<AbstractDomNode>[];
export interface AbstractDomElement {
    tag: string;
    attrs: {
        [p: string]: any;
    };
    children: DomElementChildren;
}
/**
 * Creates an abstract dom elements tree.
 * Example:
 *
 * ```ts
 * vdom('p', {}, [
 *      "Here is a",
 *      vdom("a", { href:"http://www.google.com/" }, "link"),
 *      "."
 * ]);
 * ```
 *
 * Results:
 *
 * ```html
 * <p>Here is a <a href="http://www.google.com/">link</a>.</p>
 * ```
 */
export declare function vdom(tag: string, attrs?: {
    [key: string]: any;
}, children?: DomElementChildrenFrom): AbstractDomElement;
export declare function toJsx<T>(reactCreateElement: any, root: AbstractDomElement, key?: any): T;
export declare function toHtmlDom<T extends HTMLElement>(documentCreateElement: any, document: HTMLDocument, root: AbstractDomElement): T;
export declare function toHtmlString(root: AbstractDomElement): string;
